/*
 * Copyright (c) 2019 Nordic Semiconductor ASA
 *
 * SPDX-License-Identifier: LicenseRef-Nordic-5-Clause
 */

/** @file
 *  @brief Nordic Battery Service Client sample
 */

#include <zephyr/types.h>
#include <stddef.h>
#include <inttypes.h>
#include <errno.h>
#include <zephyr.h>
#include <sys/printk.h>

#include <bluetooth/bluetooth.h>
#include <bluetooth/hci.h>
#include <bluetooth/conn.h>
#include <bluetooth/uuid.h>
#include <bluetooth/gatt.h>
#include <bluetooth/gatt_dm.h>
#include <bluetooth/scan.h>
#include <bluetooth/services/bas_client.h>
#include <dk_buttons_and_leds.h>

#include <settings/settings.h>

#include <logging/log.h>

/**
 * Button to read the battery value
 */

static void scan_filter_match(struct bt_scan_device_info *device_info,
			      struct bt_scan_filter_match *filter_match,
			      bool connectable)
{
	char addr[BT_ADDR_LE_STR_LEN];

	bt_addr_le_to_str(device_info->recv_info->addr, addr, sizeof(addr));

	printk("Filters matched. Address: %s connectable: %s\n",
		addr, connectable ? "yes" : "no");
}


static void scan_filter_no_match(struct bt_scan_device_info *device_info,
				 bool connectable)
{
	//int err;
	char addr[BT_ADDR_LE_STR_LEN];

        printk("No Match. Adv Type: 0x%02X Props: 0x%04X\n", device_info->recv_info->adv_type, device_info->recv_info->adv_props);

	if (device_info->recv_info->adv_type == BT_GAP_ADV_TYPE_ADV_DIRECT_IND) {
		bt_addr_le_to_str(device_info->recv_info->addr, addr,
				  sizeof(addr));
		printk("Direct advertising received from %s\n", addr);
		//bt_scan_stop();

	}
}

BT_SCAN_CB_INIT(scan_cb, scan_filter_match, scan_filter_no_match,
		NULL, NULL);

static void scan_init(void)
{
	int err;

	struct bt_scan_init_param scan_init = {
		.connect_if_match = 0,
		.scan_param = NULL,
		.conn_param = BT_LE_CONN_PARAM_DEFAULT
	};

	bt_scan_init(&scan_init);
	bt_scan_cb_register(&scan_cb);
}

static void bt_ready(int err)
{
  char addr_s[BT_ADDR_LE_STR_LEN];
  bt_addr_le_t addr = {0};
  size_t count = 1;

  if (IS_ENABLED(CONFIG_SETTINGS)) {
          settings_load();
  }
  bt_id_get(&addr, &count);
  bt_addr_le_to_str(&addr, addr_s, sizeof(addr_s));


  printk("Starting 12 - Directed Advertising Scanner\n");
  printk("Addr: %s\n", addr_s);

  printk("Bluetooth initialized\n");

  scan_init();

  err = bt_scan_start(BT_SCAN_TYPE_SCAN_ACTIVE);
  if (err) {
          printk("Scanning failed to start (err %d)\n", err);
          return;
  }

  printk("Scanning successfully started\n");
}

void main(void)
{
  int err;

  err = bt_enable(bt_ready);
  if (err) {
          printk("Bluetooth init failed (err %d)\n", err);
          return;
  }
}

